@@ -7,17 +7,15 @@
 Wandbox CLI for Python
 """
 
-import wandbox
-
-import argparse
+import os
 import sys
 import json
 
+from wandbox import __version__ as VERSION
 from .wandbox import Wandbox
 from .runner import Runner
 from argparse import ArgumentParser
-
-VERSION = wandbox.__version__
+from argparse import SUPPRESS
 
 
 def get_compiler_list(retry, wait):
@@ -122,6 +120,12 @@ class CLI:
         runner.build_compiler_options(args.compile_options)
 
     def run(self, args, options):
+        if args.language and args.compiler is None:
+            r = get_compiler_list(args.retry, args.retry_wait)
+            for d in r:
+                if args.language == d['language']:
+                    args.compiler = d['name']
+                    break
         runner = self.get_runner(args, options)
         self.setup_runner(args, options, [], runner)
         self.run_with_runner(args, runner)
@@ -150,13 +154,13 @@ class CLI:
             '-l',
             '--language',
             default=lang,
-            help=argparse.SUPPRESS if lang else 'specify language'
+            help=SUPPRESS if lang else 'specify language'
         )
         self.parser.add_argument(
             '-c',
             '--compiler',
             default=compiler,
-            help=argparse.SUPPRESS if compiler else 'specify compiler'
+            help=SUPPRESS if compiler else 'specify compiler'
         )
         self.parser.add_argument(
             '-x',
@@ -227,6 +231,12 @@ class CLI:
             help='show support compilers. see `compiler -h`')
         compiler_cmd.set_defaults(handler=self.command_compiler)
 
+        compiler_cmd = subparser.add_parser(
+            'versions',
+            description='show support compilers',
+            help='show support compilers. see `versions -h`')
+        compiler_cmd.set_defaults(handler=self.command_compiler)
+
         lang_cmd = subparser.add_parser(
             'lang',
             description='show support languages',
@@ -280,6 +290,8 @@ class CLI:
 
     def parse_command_line(self):
         args = self.parser.parse_args()
+        if 'WANDBOX_DRYRUN' in os.environ:
+            args.dryrun = True
         return args
 
     def print_help(self):
